unit mwIDEInspect;
{
  Vcl IDEInspect Expert

  Author:  Martin_Waldenburg
  Created: 8.98
  Version: 1.1 beta
  Status: FreWare
  CAUTION:
  Using of mIDEIns4 may be dangerous.
  It may shoot down Delphi and Windows too.
  mIDEIns4 is provided as is, especially without a warranty of any kind.
  You use it at your own risc.
}

interface

uses SysUtils,
  Classes,
  Messages,
  Consts,
  Forms,
  Windows,
  Dialogs,
  ClipBrd,
  Controls,
  ToolsApi,
  ExtCtrls,
  Menus,
  comCtrls,
  StdCtrls,
  LibIntf,
  TypInfo,
  WinTypes,
  E_Props,
  E_cmpEd,
  ImageWin,
  ViewImg,
  StrEdit;

type
  TfrmIDEInspect = class(TForm)
    TreeView1: TTreeView;
    procedure FormShow(Sender: TObject);
    procedure TreeView1Deletion(Sender: TObject; Node: TTreeNode);
    procedure TreeView1Change(Sender: TObject; Node: TTreeNode);
    procedure FormCreate(Sender: TObject);
  private
    { private declarations }
  public
    { public declarations }
  end;

  TIDEInspectExpert = class(TInterfacedObject, IOTAMenuWizard, IOTAWizard)
  private
  protected
  public
    constructor Create; virtual;
    destructor Destroy; override;
    function GetName: string;
    function GetAuthor: string;
    function GetIDString: string;
    procedure AfterSave;
    procedure BeforeSave;
    procedure Modified;
    procedure Destroyed;
    procedure Execute;
    function GetMenuText: string;
    function GetState: TWizardState;
  end;

procedure Register;

var
  frmIDEInspect: TfrmIDEInspect;

implementation

{$R *.DFM}

procedure Register;
begin
  RegisterPackageWizard(TIDEInspectExpert.Create);
end;

{ TIDEInspectExpert code }
function TIDEInspectExpert.GetName: String;
begin
  Result := 'IDEInspectExpert'
end;

function TIDEInspectExpert.GetAuthor: String;
begin
  Result := 'Martin_Waldenburg'; { author }
end;

function TIDEInspectExpert.GetIDString: String;
begin
  Result := 'private.IDEInspectExpert';
end;

function AddType(aNode: TTreeNode; Name: String; aComponent: TComponent): TTreeNode;
begin
  Result:= frmIDEInspect.TreeView1.Items.AddChild(aNode, Name + ': ' + PTypeInfo(aComponent.ClassInfo)^.Name);
  Result.Data:= aComponent;
end;

procedure ScanComponents(aNode: TTreeNode; aComponent: TComponent);
var
  I: Integer;
begin
  aNode:= AddType(aNode, aComponent.Name, aComponent);
  for I:= 0 to aComponent.ComponentCount -1 do
  begin
   ScanComponents(aNode, aComponent.Components[I]);
  end;
  aComponent:= nil;
end;

procedure LookupStuff;
Begin
  ScanComponents(nil, Application);
End;


{ TfrmIDEInspect code }

procedure TfrmIDEInspect.FormShow(Sender: TObject);
begin
  TreeView1.Items.BeginUpdate;
  TreeView1.Items.Clear;
  CompEditForm.Execute(self, False);
  LookupStuff;
  TreeView1.Items.EndUpdate;
end;

procedure TfrmIDEInspect.TreeView1Deletion(Sender: TObject; Node: TTreeNode);
begin
  Node.Data:= nil;
end;

procedure TIDEInspectExpert.AfterSave;
begin

end;

procedure TIDEInspectExpert.BeforeSave;
begin

end;

constructor TIDEInspectExpert.Create;
begin

end;

destructor TIDEInspectExpert.Destroy;
begin
  inherited Destroy;
  frmIDEInspect.Free;
end;

procedure TIDEInspectExpert.Destroyed;
begin

end;

procedure TIDEInspectExpert.Execute;
begin
  if not Assigned(frmIDEInspect) then
    frmIDEInspect := TfrmIDEInspect.Create(nil);
  frmIDEInspect.Show;
  frmIDEInspect.SetFocus
end;

function TIDEInspectExpert.GetMenuText: string;
begin
  Result:= 'IDEInspect';
end;

function TIDEInspectExpert.GetState: TWizardState;
begin
  Result := [wsEnabled];
end;

procedure TIDEInspectExpert.Modified;
begin

end;

procedure TfrmIDEInspect.TreeView1Change(Sender: TObject; Node: TTreeNode);
var
  aComponent: TComponent;
begin
  try
    with TreeView1 do
    begin
      aComponent:= Node.Data;
      CompEditForm.Execute(aComponent, False);
    end;
  finally
  end;
end;

procedure TfrmIDEInspect.FormCreate(Sender: TObject);
begin
  Application.CreateForm(TCompEditForm, CompEditForm);
  Application.CreateForm(TImageForm, ImageForm);
  Application.CreateForm(TViewImageForm, ViewImageForm);
  Application.CreateForm(TSedForm, SedForm);
end;

end.
